"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def accept(hub, ctx, graph_arn: str) -> None:
    r"""
    **Autogenerated function**

    Accepts an invitation for the member account to contribute data to a behavior graph. This operation can only be called by an invited member account.  The request provides the ARN of behavior graph. The member account status in the graph must be INVITED.

    Args:
        graph_arn(str): The ARN of the behavior graph that the member account is accepting the invitation for. The member account status in the behavior graph must be INVITED.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.detective.invitation.accept(ctx, graph_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.detective.invitation.accept graph_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="detective",
        operation="accept_invitation",
        op_kwargs={"GraphArn": graph_arn},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the list of open and accepted behavior graph invitations for the member account. This operation can only be called by a member account. Open invitations are invitations that the member account has not responded to. The results do not include behavior graphs for which the member account declined the invitation. The results also do not include behavior graphs that the member account resigned from or was removed from.

    Args:
        next_token(str, optional): For requests to retrieve the next page of results, the pagination token that was returned with the previous page of results. The initial request does not include a pagination token. Defaults to None.
        max_results(int, optional): The maximum number of behavior graph invitations to return in the response. The total must be less than the overall limit on the number of results to return, which is currently 200. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.detective.invitation.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.detective.invitation.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="detective",
        operation="list_invitations",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def reject(hub, ctx, graph_arn: str) -> None:
    r"""
    **Autogenerated function**

    Rejects an invitation to contribute the account data to a behavior graph. This operation must be called by a member account that has the INVITED status.

    Args:
        graph_arn(str): The ARN of the behavior graph to reject the invitation to. The member account's current member status in the behavior graph must be INVITED.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.detective.invitation.reject(ctx, graph_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.detective.invitation.reject graph_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="detective",
        operation="reject_invitation",
        op_kwargs={"GraphArn": graph_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    listener_arn: str,
    endpoint_group_region: str,
    destination_configurations: List,
    idempotency_token: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Create an endpoint group for the specified listener for a custom routing accelerator. An endpoint group is a collection of endpoints in one AWS Region.

    Args:
        listener_arn(str): The Amazon Resource Name (ARN) of the listener for a custom routing endpoint.
        endpoint_group_region(str): The AWS Region where the endpoint group is located. A listener can have only one endpoint group in a specific Region.
        destination_configurations(List): Sets the port range and protocol for all endpoints (virtual private cloud subnets) in a custom routing endpoint group to accept client traffic on.
        idempotency_token(str): A unique, case-sensitive identifier that you provide to ensure the idempotency—that is, the uniqueness—of the request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.endpoint.group.create(
                ctx,
                listener_arn=value,
                endpoint_group_region=value,
                destination_configurations=value,
                idempotency_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.endpoint.group.create listener_arn=value, endpoint_group_region=value, destination_configurations=value, idempotency_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="create_custom_routing_endpoint_group",
        op_kwargs={
            "ListenerArn": listener_arn,
            "EndpointGroupRegion": endpoint_group_region,
            "DestinationConfigurations": destination_configurations,
            "IdempotencyToken": idempotency_token,
        },
    )


async def delete(hub, ctx, endpoint_group_arn: str) -> None:
    r"""
    **Autogenerated function**

    Delete an endpoint group from a listener for a custom routing accelerator.

    Args:
        endpoint_group_arn(str): The Amazon Resource Name (ARN) of the endpoint group to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.endpoint.group.delete(
                ctx, endpoint_group_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.endpoint.group.delete endpoint_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="delete_custom_routing_endpoint_group",
        op_kwargs={"EndpointGroupArn": endpoint_group_arn},
    )


async def describe(hub, ctx, endpoint_group_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describe an endpoint group for a custom routing accelerator.

    Args:
        endpoint_group_arn(str): The Amazon Resource Name (ARN) of the endpoint group to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.endpoint.group.describe(
                ctx, endpoint_group_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.endpoint.group.describe endpoint_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="describe_custom_routing_endpoint_group",
        op_kwargs={"EndpointGroupArn": endpoint_group_arn},
    )


async def list_all(
    hub, ctx, listener_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    List the endpoint groups that are associated with a listener for a custom routing accelerator.

    Args:
        listener_arn(str): The Amazon Resource Name (ARN) of the listener to list endpoint groups for.
        max_results(int, optional): The number of endpoint group objects that you want to return with this call. The default value is 10. Defaults to None.
        next_token(str, optional): The token for the next set of results. You receive this token from a previous call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.endpoint.group.list_all(
                ctx, listener_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.endpoint.group.list_all listener_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="list_custom_routing_endpoint_groups",
        op_kwargs={
            "ListenerArn": listener_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, device_id: str, tracker_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a device's most recent position according to its sample time.  Device positions are deleted after 30 days.

    Args:
        device_id(str): The device whose position you want to retrieve.
        tracker_name(str): The tracker resource receiving the position update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.device_position.init.get(
                ctx, device_id=value, tracker_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.device_position.init.get device_id=value, tracker_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="get_device_position",
        op_kwargs={"DeviceId": device_id, "TrackerName": tracker_name},
    )


async def list_all(
    hub, ctx, tracker_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    A batch request to retrieve all device positions.

    Args:
        max_results(int, optional): An optional limit for the number of entries returned in a single call. Default value: 100 . Defaults to None.
        next_token(str, optional): The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page. Default value: null . Defaults to None.
        tracker_name(str): The tracker resource containing the requested devices.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.device_position.init.list_all(ctx, tracker_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.device_position.init.list_all tracker_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="list_device_positions",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "TrackerName": tracker_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    approval_rule_template_name: str,
    approval_rule_template_content: str,
    approval_rule_template_description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a template for approval rules that can then be associated with one or more repositories in your AWS account. When you associate a template with a repository, AWS CodeCommit creates an approval rule that matches the conditions of the template for all pull requests that meet the conditions of the template. For more information, see AssociateApprovalRuleTemplateWithRepository.

    Args:
        approval_rule_template_name(str): The name of the approval rule template. Provide descriptive names, because this name is applied to the approval rules created automatically in associated repositories.
        approval_rule_template_content(str): The content of the approval rule that is created on pull requests in associated repositories. If you specify one or more destination references (branches), approval rules are created in an associated repository only if their destination references (branches) match those specified in the template.  When you create the content of the approval rule template, you can specify approvers in an approval pool in one of two ways:    CodeCommitApprovers: This option only requires an AWS account and a resource. It can be used for both IAM users and federated access users whose name matches the provided resource name. This is a very powerful option that offers a great deal of flexibility. For example, if you specify the AWS account 123456789012 and Mary_Major, all of the following are counted as approvals coming from that user:   An IAM user in the account (arn:aws:iam::123456789012:user/Mary_Major)   A federated user identified in IAM as Mary_Major (arn:aws:sts::123456789012:federated-user/Mary_Major)   This option does not recognize an active session of someone assuming the role of CodeCommitReview with a role session name of Mary_Major (arn:aws:sts::123456789012:assumed-role/CodeCommitReview/Mary_Major) unless you include a wildcard (*Mary_Major).    Fully qualified ARN: This option allows you to specify the fully qualified Amazon Resource Name (ARN) of the IAM user or role.    For more information about IAM ARNs, wildcards, and formats, see IAM Identifiers in the IAM User Guide. .
        approval_rule_template_description(str, optional): The description of the approval rule template. Consider providing a description that explains what this template does and when it might be appropriate to associate it with repositories. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.approval_rule_template.init.create(
                ctx, approval_rule_template_name=value, approval_rule_template_content=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.approval_rule_template.init.create approval_rule_template_name=value, approval_rule_template_content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="create_approval_rule_template",
        op_kwargs={
            "approvalRuleTemplateName": approval_rule_template_name,
            "approvalRuleTemplateContent": approval_rule_template_content,
            "approvalRuleTemplateDescription": approval_rule_template_description,
        },
    )


async def delete(hub, ctx, approval_rule_template_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specified approval rule template. Deleting a template does not remove approval rules on pull requests already created with the template.

    Args:
        approval_rule_template_name(str): The name of the approval rule template to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.approval_rule_template.init.delete(
                ctx, approval_rule_template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.approval_rule_template.init.delete approval_rule_template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="delete_approval_rule_template",
        op_kwargs={"approvalRuleTemplateName": approval_rule_template_name},
    )


async def get(hub, ctx, approval_rule_template_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specified approval rule template.

    Args:
        approval_rule_template_name(str): The name of the approval rule template for which you want to get information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.approval_rule_template.init.get(
                ctx, approval_rule_template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.approval_rule_template.init.get approval_rule_template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="get_approval_rule_template",
        op_kwargs={"approvalRuleTemplateName": approval_rule_template_name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all approval rule templates in the specified AWS Region in your AWS account. If an AWS Region is not specified, the AWS Region where you are signed in is used.

    Args:
        next_token(str, optional): An enumeration token that, when provided in a request, returns the next batch of the results. Defaults to None.
        max_results(int, optional): A non-zero, non-negative integer used to limit the number of returned results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.approval_rule_template.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.approval_rule_template.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="list_approval_rule_templates",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, task_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a bulk thing provisioning task.

    Args:
        task_id(str): The task ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.registration_task.init.describe(ctx, task_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.registration_task.init.describe task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_thing_registration_task",
        op_kwargs={"taskId": task_id},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, status: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    List bulk thing provisioning tasks.

    Args:
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return at one time. Defaults to None.
        status(str, optional): The status of the bulk thing provisioning task. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.registration_task.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.registration_task.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_thing_registration_tasks",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "status": status,
        },
    )


async def start(
    hub,
    ctx,
    template_body: str,
    input_file_bucket: str,
    input_file_key: str,
    role_arn: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a bulk thing provisioning task.

    Args:
        template_body(str): The provisioning template.
        input_file_bucket(str): The S3 bucket that contains the input file.
        input_file_key(str): The name of input file within the S3 bucket. This file contains a newline delimited JSON file. Each line contains the parameter values to provision one device (thing).
        role_arn(str): The IAM role ARN that grants permission the input file.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.registration_task.init.start(
                ctx,
                template_body=value,
                input_file_bucket=value,
                input_file_key=value,
                role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.registration_task.init.start template_body=value, input_file_bucket=value, input_file_key=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="start_thing_registration_task",
        op_kwargs={
            "templateBody": template_body,
            "inputFileBucket": input_file_bucket,
            "inputFileKey": input_file_key,
            "roleArn": role_arn,
        },
    )


async def stop(hub, ctx, task_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a bulk thing provisioning task.

    Args:
        task_id(str): The bulk thing provisioning task ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.registration_task.init.stop(ctx, task_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.registration_task.init.stop task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="stop_thing_registration_task",
        op_kwargs={"taskId": task_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def revoke(hub, ctx, user_arn: str = None, enrollment_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Revokes an invitation and invalidates the enrollment URL.

    Args:
        user_arn(str, optional): The ARN of the user for whom to revoke an enrollment invitation. Required. Defaults to None.
        enrollment_id(str, optional): The ARN of the enrollment invitation to revoke. Required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.invitation.init.revoke(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.invitation.init.revoke
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="revoke_invitation",
        op_kwargs={"UserArn": user_arn, "EnrollmentId": enrollment_id},
    )


async def send(hub, ctx, user_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Sends an enrollment invitation email with a URL to a user. The URL is valid for 30 days or until you call this operation again, whichever comes first.

    Args:
        user_arn(str, optional): The ARN of the user to whom to send an invitation. Required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.invitation.init.send(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.invitation.init.send
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="send_invitation",
        op_kwargs={"UserArn": user_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, next_token: str = None, max_results: int = None, product_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about product integrations in Security Hub. You can optionally provide an integration ARN. If you provide an integration ARN, then the results only include that integration. If you do not provide an integration ARN, then the results include all of the available product integrations.

    Args:
        next_token(str, optional): The token that is required for pagination. On your first call to the DescribeProducts operation, set the value of this parameter to NULL. For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        product_arn(str, optional): The ARN of the integration to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.product.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.product.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="describe_products",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "ProductArn": product_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    insight_id: str,
    start_time_range: Dict = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of the anomalies that belong to an insight that you specify using its ID.

    Args:
        insight_id(str):  The ID of the insight. The returned anomalies belong to this insight. .
        start_time_range(Dict, optional):  A time range used to specify when the requested anomalies started. All returned anomalies started during this time range. . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.anomaly.for_insight.list(ctx, insight_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.anomaly.for_insight.list insight_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="list_anomalies_for_insight",
        op_kwargs={
            "InsightId": insight_id,
            "StartTimeRange": start_time_range,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    subscription_name: str,
    sns_topic_arn: str,
    source_type: str = None,
    event_categories: List = None,
    source_ids: List = None,
    enabled: bool = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an event notification subscription. This action requires a topic ARN (Amazon Resource Name) created by either the Neptune console, the SNS console, or the SNS API. To obtain an ARN with SNS, you must create a topic in Amazon SNS and subscribe to the topic. The ARN is displayed in the SNS console. You can specify the type of source (SourceType) you want to be notified of, provide a list of Neptune sources (SourceIds) that triggers the events, and provide a list of event categories (EventCategories) for events you want to be notified of. For example, you can specify SourceType = db-instance, SourceIds = mydbinstance1, mydbinstance2 and EventCategories = Availability, Backup. If you specify both the SourceType and SourceIds, such as SourceType = db-instance and SourceIdentifier = myDBInstance1, you are notified of all the db-instance events for the specified source. If you specify a SourceType but do not specify a SourceIdentifier, you receive notice of the events for that source type for all your Neptune sources. If you do not specify either the SourceType nor the SourceIdentifier, you are notified of events generated from all Neptune sources belonging to your customer account.

    Args:
        subscription_name(str): The name of the subscription. Constraints: The name must be less than 255 characters.
        sns_topic_arn(str): The Amazon Resource Name (ARN) of the SNS topic created for event notification. The ARN is created by Amazon SNS when you create a topic and subscribe to it.
        source_type(str, optional): The type of source that is generating the events. For example, if you want to be notified of events generated by a DB instance, you would set this parameter to db-instance. if this value is not specified, all events are returned. Valid values: db-instance | db-cluster | db-parameter-group | db-security-group | db-snapshot | db-cluster-snapshot . Defaults to None.
        event_categories(List, optional):  A list of event categories for a SourceType that you want to subscribe to. You can see a list of the categories for a given SourceType by using the DescribeEventCategories action. Defaults to None.
        source_ids(List, optional): The list of identifiers of the event sources for which events are returned. If not specified, then all sources are included in the response. An identifier must begin with a letter and must contain only ASCII letters, digits, and hyphens; it can't end with a hyphen or contain two consecutive hyphens. Constraints:   If SourceIds are supplied, SourceType must also be provided.   If the source type is a DB instance, then a DBInstanceIdentifier must be supplied.   If the source type is a DB security group, a DBSecurityGroupName must be supplied.   If the source type is a DB parameter group, a DBParameterGroupName must be supplied.   If the source type is a DB snapshot, a DBSnapshotIdentifier must be supplied.  . Defaults to None.
        enabled(bool, optional):  A Boolean value; set to true to activate the subscription, set to false to create the subscription but not active it. Defaults to None.
        tags(List, optional): The tags to be applied to the new event subscription. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.event.subscription.create(
                ctx, subscription_name=value, sns_topic_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.event.subscription.create subscription_name=value, sns_topic_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="create_event_subscription",
        op_kwargs={
            "SubscriptionName": subscription_name,
            "SnsTopicArn": sns_topic_arn,
            "SourceType": source_type,
            "EventCategories": event_categories,
            "SourceIds": source_ids,
            "Enabled": enabled,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, subscription_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an event notification subscription.

    Args:
        subscription_name(str): The name of the event notification subscription you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.event.subscription.delete(ctx, subscription_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.event.subscription.delete subscription_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="delete_event_subscription",
        op_kwargs={"SubscriptionName": subscription_name},
    )


async def describe_all(
    hub,
    ctx,
    subscription_name: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the subscription descriptions for a customer account. The description for a subscription includes SubscriptionName, SNSTopicARN, CustomerID, SourceType, SourceID, CreationTime, and Status. If you specify a SubscriptionName, lists the description for that subscription.

    Args:
        subscription_name(str, optional): The name of the event notification subscription you want to describe. Defaults to None.
        filters(List, optional): This parameter is not currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous DescribeOrderableDBInstanceOptions request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.event.subscription.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.event.subscription.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="describe_event_subscriptions",
        op_kwargs={
            "SubscriptionName": subscription_name,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def modify(
    hub,
    ctx,
    subscription_name: str,
    sns_topic_arn: str = None,
    source_type: str = None,
    event_categories: List = None,
    enabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies an existing event notification subscription. Note that you can't modify the source identifiers using this call; to change source identifiers for a subscription, use the AddSourceIdentifierToSubscription and RemoveSourceIdentifierFromSubscription calls. You can see a list of the event categories for a given SourceType by using the DescribeEventCategories action.

    Args:
        subscription_name(str): The name of the event notification subscription.
        sns_topic_arn(str, optional): The Amazon Resource Name (ARN) of the SNS topic created for event notification. The ARN is created by Amazon SNS when you create a topic and subscribe to it. Defaults to None.
        source_type(str, optional): The type of source that is generating the events. For example, if you want to be notified of events generated by a DB instance, you would set this parameter to db-instance. if this value is not specified, all events are returned. Valid values: db-instance | db-parameter-group | db-security-group | db-snapshot. Defaults to None.
        event_categories(List, optional):  A list of event categories for a SourceType that you want to subscribe to. You can see a list of the categories for a given SourceType by using the DescribeEventCategories action. Defaults to None.
        enabled(bool, optional):  A Boolean value; set to true to activate the subscription. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.event.subscription.modify(ctx, subscription_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.event.subscription.modify subscription_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="modify_event_subscription",
        op_kwargs={
            "SubscriptionName": subscription_name,
            "SnsTopicArn": sns_topic_arn,
            "SourceType": source_type,
            "EventCategories": event_categories,
            "Enabled": enabled,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    organization_config_rule_name: str,
    filters: Dict = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns detailed status for each member account within an organization for a given organization config rule.

    Args:
        organization_config_rule_name(str): The name of organization config rule for which you want status details for member accounts.
        filters(Dict, optional): A StatusDetailFilters object. Defaults to None.
        limit(int, optional): The maximum number of OrganizationConfigRuleDetailedStatus returned on each page. If you do not specify a number, AWS Config uses the default. The default is 100. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.organization.config_rule.detailed_status.get(
                ctx, organization_config_rule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.organization.config_rule.detailed_status.get organization_config_rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="get_organization_config_rule_detailed_status",
        op_kwargs={
            "OrganizationConfigRuleName": organization_config_rule_name,
            "Filters": filters,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    http_package_configurations: List,
    source_location_name: str,
    vod_source_name: str,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates name for a specific VOD source in a source location.

    Args:
        http_package_configurations(List): An array of HTTP package configuration parameters for this VOD source.
        source_location_name(str): The identifier for the source location you are working on.
        tags(Dict, optional): The tags to assign to the VOD source. Defaults to None.
        vod_source_name(str): The identifier for the VOD source you are working on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.vod_source.create(
                ctx,
                http_package_configurations=value,
                source_location_name=value,
                vod_source_name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.vod_source.create http_package_configurations=value, source_location_name=value, vod_source_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="create_vod_source",
        op_kwargs={
            "HttpPackageConfigurations": http_package_configurations,
            "SourceLocationName": source_location_name,
            "Tags": tags,
            "VodSourceName": vod_source_name,
        },
    )


async def delete(hub, ctx, source_location_name: str, vod_source_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specific VOD source in a specific source location.

    Args:
        source_location_name(str): The identifier for the source location you are working on.
        vod_source_name(str): The identifier for the VOD source you are working on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.vod_source.delete(
                ctx, source_location_name=value, vod_source_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.vod_source.delete source_location_name=value, vod_source_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="delete_vod_source",
        op_kwargs={
            "SourceLocationName": source_location_name,
            "VodSourceName": vod_source_name,
        },
    )


async def describe(hub, ctx, source_location_name: str, vod_source_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides details about a specific VOD source in a specific source location.

    Args:
        source_location_name(str): The identifier for the source location you are working on.
        vod_source_name(str): The identifier for the VOD source you are working on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.vod_source.describe(
                ctx, source_location_name=value, vod_source_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.vod_source.describe source_location_name=value, vod_source_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="describe_vod_source",
        op_kwargs={
            "SourceLocationName": source_location_name,
            "VodSourceName": vod_source_name,
        },
    )


async def list_all(
    hub, ctx, source_location_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the VOD sources in a source location.

    Args:
        max_results(int, optional): Upper bound on number of records to return. The maximum number of results is 100. Defaults to None.
        next_token(str, optional): Pagination token from the GET list request. Use the token to fetch the next page of results. Defaults to None.
        source_location_name(str): The identifier for the source location you are working on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.vod_source.list_all(ctx, source_location_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.vod_source.list_all source_location_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="list_vod_sources",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "SourceLocationName": source_location_name,
        },
    )


async def update(
    hub,
    ctx,
    http_package_configurations: List,
    source_location_name: str,
    vod_source_name: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a specific VOD source in a specific source location.

    Args:
        http_package_configurations(List): An array of HTTP package configurations for the VOD source on this account.
        source_location_name(str): The identifier for the source location you are working on.
        vod_source_name(str): The identifier for the VOD source you are working on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.vod_source.update(
                ctx,
                http_package_configurations=value,
                source_location_name=value,
                vod_source_name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.vod_source.update http_package_configurations=value, source_location_name=value, vod_source_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="update_vod_source",
        op_kwargs={
            "HttpPackageConfigurations": http_package_configurations,
            "SourceLocationName": source_location_name,
            "VodSourceName": vod_source_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, reserved_instances_listing_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels the specified Reserved Instance listing in the Reserved Instance Marketplace. For more information, see Reserved Instance Marketplace in the Amazon EC2 User Guide.

    Args:
        reserved_instances_listing_id(str): The ID of the Reserved Instance listing.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.reserved_instance.listing.cancel(
                ctx, reserved_instances_listing_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.reserved_instance.listing.cancel reserved_instances_listing_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="cancel_reserved_instances_listing",
        op_kwargs={"ReservedInstancesListingId": reserved_instances_listing_id},
    )


async def create(
    hub,
    ctx,
    client_token: str,
    instance_count: int,
    price_schedules: List,
    reserved_instances_id: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a listing for Amazon EC2 Standard Reserved Instances to be sold in the Reserved Instance Marketplace. You can submit one Standard Reserved Instance listing at a time. To get a list of your Standard Reserved Instances, you can use the DescribeReservedInstances operation.  Only Standard Reserved Instances can be sold in the Reserved Instance Marketplace. Convertible Reserved Instances cannot be sold.  The Reserved Instance Marketplace matches sellers who want to resell Standard Reserved Instance capacity that they no longer need with buyers who want to purchase additional capacity. Reserved Instances bought and sold through the Reserved Instance Marketplace work like any other Reserved Instances. To sell your Standard Reserved Instances, you must first register as a seller in the Reserved Instance Marketplace. After completing the registration process, you can create a Reserved Instance Marketplace listing of some or all of your Standard Reserved Instances, and specify the upfront price to receive for them. Your Standard Reserved Instance listings then become available for purchase. To view the details of your Standard Reserved Instance listing, you can use the DescribeReservedInstancesListings operation. For more information, see Reserved Instance Marketplace in the Amazon EC2 User Guide.

    Args:
        client_token(str): Unique, case-sensitive identifier you provide to ensure idempotency of your listings. This helps avoid duplicate listings. For more information, see Ensuring Idempotency.
        instance_count(int): The number of instances that are a part of a Reserved Instance account to be listed in the Reserved Instance Marketplace. This number should be less than or equal to the instance count associated with the Reserved Instance ID specified in this call.
        price_schedules(List): A list specifying the price of the Standard Reserved Instance for each month remaining in the Reserved Instance term.
        reserved_instances_id(str): The ID of the active Standard Reserved Instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.reserved_instance.listing.create(
                ctx,
                client_token=value,
                instance_count=value,
                price_schedules=value,
                reserved_instances_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.reserved_instance.listing.create client_token=value, instance_count=value, price_schedules=value, reserved_instances_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_reserved_instances_listing",
        op_kwargs={
            "ClientToken": client_token,
            "InstanceCount": instance_count,
            "PriceSchedules": price_schedules,
            "ReservedInstancesId": reserved_instances_id,
        },
    )


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    reserved_instances_id: str = None,
    reserved_instances_listing_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes your account's Reserved Instance listings in the Reserved Instance Marketplace. The Reserved Instance Marketplace matches sellers who want to resell Reserved Instance capacity that they no longer need with buyers who want to purchase additional capacity. Reserved Instances bought and sold through the Reserved Instance Marketplace work like any other Reserved Instances. As a seller, you choose to list some or all of your Reserved Instances, and you specify the upfront price to receive for them. Your Reserved Instances are then listed in the Reserved Instance Marketplace and are available for purchase. As a buyer, you specify the configuration of the Reserved Instance to purchase, and the Marketplace matches what you're searching for with what's available. The Marketplace first sells the lowest priced Reserved Instances to you, and continues to sell available Reserved Instance listings to you until your demand is met. You are charged based on the total price of all of the listings that you purchase. For more information, see Reserved Instance Marketplace in the Amazon EC2 User Guide.

    Args:
        filters(List, optional): One or more filters.    reserved-instances-id - The ID of the Reserved Instances.    reserved-instances-listing-id - The ID of the Reserved Instances listing.    status - The status of the Reserved Instance listing (pending | active | cancelled | closed).    status-message - The reason for the status.  . Defaults to None.
        reserved_instances_id(str, optional): One or more Reserved Instance IDs. Defaults to None.
        reserved_instances_listing_id(str, optional): One or more Reserved Instance listing IDs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.reserved_instance.listing.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.reserved_instance.listing.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_reserved_instances_listings",
        op_kwargs={
            "Filters": filters,
            "ReservedInstancesId": reserved_instances_id,
            "ReservedInstancesListingId": reserved_instances_listing_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, analyzer_arn: str, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the specified finding.

    Args:
        analyzer_arn(str): The ARN of the analyzer that generated the finding.
        id_(str): The ID of the finding to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.finding.get(ctx, analyzer_arn=value, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.finding.get analyzer_arn=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="get_finding",
        op_kwargs={"analyzerArn": analyzer_arn, "id": id_},
    )


async def list_all(
    hub,
    ctx,
    analyzer_arn: str,
    filter_: Dict = None,
    max_results: int = None,
    next_token: str = None,
    sort: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of findings generated by the specified analyzer. To learn about filter keys that you can use to retrieve a list of findings, see Access Analyzer filter keys in the IAM User Guide.

    Args:
        analyzer_arn(str): The ARN of the analyzer to retrieve findings from.
        filter_(Dict, optional): A filter to match for the findings to return. Defaults to None.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.
        next_token(str, optional): A token used for pagination of results returned. Defaults to None.
        sort(Dict, optional): The sort order for the findings returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.finding.list_all(ctx, analyzer_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.finding.list_all analyzer_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="list_findings",
        op_kwargs={
            "analyzerArn": analyzer_arn,
            "filter": filter_,
            "maxResults": max_results,
            "nextToken": next_token,
            "sort": sort,
        },
    )


async def update_multiple(
    hub,
    ctx,
    analyzer_arn: str,
    status: str,
    client_token: str = None,
    ids: List = None,
    resource_arn: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates the status for the specified findings.

    Args:
        analyzer_arn(str): The ARN of the analyzer that generated the findings to update.
        client_token(str, optional): A client token. Defaults to None.
        ids(List, optional): The IDs of the findings to update. Defaults to None.
        resource_arn(str, optional): The ARN of the resource identified in the finding. Defaults to None.
        status(str): The state represents the action to take to update the finding Status. Use ARCHIVE to change an Active finding to an Archived finding. Use ACTIVE to change an Archived finding to an Active finding.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.finding.update_multiple(
                ctx, analyzer_arn=value, status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.finding.update_multiple analyzer_arn=value, status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="update_findings",
        op_kwargs={
            "analyzerArn": analyzer_arn,
            "clientToken": client_token,
            "ids": ids,
            "resourceArn": resource_arn,
            "status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "change_set"


async def cancel(hub, ctx, catalog: str, change_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Used to cancel an open change request. Must be sent before the status of the request changes to APPLYING, the final stage of completing your change request. You can describe a change during the 60-day request history retention period for API calls.

    Args:
        catalog(str): Required. The catalog related to the request. Fixed value: AWSMarketplace.
        change_set_id(str): Required. The unique identifier of the StartChangeSet request that you want to cancel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.marketplace_catalog.change_set_.cancel(
                ctx, catalog=value, change_set_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.marketplace_catalog.change_set.cancel catalog=value, change_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="marketplace-catalog",
        operation="cancel_change_set",
        op_kwargs={"Catalog": catalog, "ChangeSetId": change_set_id},
    )


async def describe(hub, ctx, catalog: str, change_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides information about a given change set.

    Args:
        catalog(str): Required. The catalog related to the request. Fixed value: AWSMarketplace .
        change_set_id(str): Required. The unique identifier for the StartChangeSet request that you want to describe the details for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.marketplace_catalog.change_set_.describe(
                ctx, catalog=value, change_set_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.marketplace_catalog.change_set.describe catalog=value, change_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="marketplace-catalog",
        operation="describe_change_set",
        op_kwargs={"Catalog": catalog, "ChangeSetId": change_set_id},
    )


async def list_all(
    hub,
    ctx,
    catalog: str,
    filter_list: List = None,
    sort: Dict = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the list of change sets owned by the account being used to make the call. You can filter this list by providing any combination of entityId, ChangeSetName, and status. If you provide more than one filter, the API operation applies a logical AND between the filters. You can describe a change during the 60-day request history retention period for API calls.

    Args:
        catalog(str): The catalog related to the request. Fixed value: AWSMarketplace .
        filter_list(List, optional): An array of filter objects. Defaults to None.
        sort(Dict, optional): An object that contains two attributes, SortBy and SortOrder. Defaults to None.
        max_results(int, optional): The maximum number of results returned by a single call. This value must be provided in the next call to retrieve the next set of results. By default, this value is 20. Defaults to None.
        next_token(str, optional): The token value retrieved from a previous call to access the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.marketplace_catalog.change_set_.list_all(ctx, catalog=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.marketplace_catalog.change_set.list_all catalog=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="marketplace-catalog",
        operation="list_change_sets",
        op_kwargs={
            "Catalog": catalog,
            "FilterList": filter_list,
            "Sort": sort,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def start(
    hub,
    ctx,
    catalog: str,
    change_set: List,
    change_set_name: str = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This operation allows you to request changes for your entities. Within a single ChangeSet, you cannot start the same change type against the same entity multiple times. Additionally, when a ChangeSet is running, all the entities targeted by the different changes are locked until the ChangeSet has completed (either succeeded, cancelled, or failed). If you try to start a ChangeSet containing a change against an entity that is already locked, you will receive a ResourceInUseException. For example, you cannot start the ChangeSet described in the example later in this topic, because it contains two changes to execute the same change type (AddRevisions) against the same entity (entity-id@1). For more information about working with change sets, see  Working with change sets.

    Args:
        catalog(str): The catalog related to the request. Fixed value: AWSMarketplace .
        change_set(List): Array of change object.
        change_set_name(str, optional): Optional case sensitive string of up to 100 ASCII characters. The change set name can be used to filter the list of change sets. . Defaults to None.
        client_request_token(str, optional): A unique token to identify the request to ensure idempotency. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.marketplace_catalog.change_set_.start(
                ctx, catalog=value, change_set=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.marketplace_catalog.change_set.start catalog=value, change_set=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="marketplace-catalog",
        operation="start_change_set",
        op_kwargs={
            "Catalog": catalog,
            "ChangeSet": change_set,
            "ChangeSetName": change_set_name,
            "ClientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    job_id: str,
    max_results: int = None,
    next_token: str = None,
    sort_by: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the unsafe content analysis results for a Amazon Rekognition Video analysis started by StartContentModeration. Unsafe content analysis of a video is an asynchronous operation. You start analysis by calling StartContentModeration which returns a job identifier (JobId). When analysis finishes, Amazon Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic registered in the initial call to StartContentModeration. To get the results of the unsafe content analysis, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetContentModeration and pass the job identifier (JobId) from the initial call to StartContentModeration.  For more information, see Working with Stored Videos in the Amazon Rekognition Devlopers Guide.  GetContentModeration returns detected unsafe content labels, and the time they are detected, in an array, ModerationLabels, of ContentModerationDetection objects.  By default, the moderated labels are returned sorted by time, in milliseconds from the start of the video. You can also sort them by moderated label by specifying NAME for the SortBy input parameter.  Since video analysis can return a large number of results, use the MaxResults parameter to limit the number of labels returned in a single call to GetContentModeration. If there are more results than specified in MaxResults, the value of NextToken in the operation response contains a pagination token for getting the next set of results. To get the next page of results, call GetContentModeration and populate the NextToken request parameter with the value of NextToken returned from the previous call to GetContentModeration. For more information, see Detecting Unsafe Content in the Amazon Rekognition Developer Guide.

    Args:
        job_id(str): The identifier for the unsafe content job. Use JobId to identify the job in a subsequent call to GetContentModeration.
        max_results(int, optional): Maximum number of results to return per paginated call. The largest value you can specify is 1000. If you specify a value greater than 1000, a maximum of 1000 results is returned. The default value is 1000. Defaults to None.
        next_token(str, optional): If the previous response was incomplete (because there is more data to retrieve), Amazon Rekognition returns a pagination token in the response. You can use this pagination token to retrieve the next set of unsafe content labels. Defaults to None.
        sort_by(str, optional): Sort to use for elements in the ModerationLabelDetections array. Use TIMESTAMP to sort array elements by the time labels are detected. Use NAME to alphabetically group elements for a label together. Within each label group, the array element are sorted by detection confidence. The default sort is by TIMESTAMP. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.content_moderation.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.content_moderation.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="get_content_moderation",
        op_kwargs={
            "JobId": job_id,
            "MaxResults": max_results,
            "NextToken": next_token,
            "SortBy": sort_by,
        },
    )


async def start(
    hub,
    ctx,
    video: Dict,
    min_confidence: float = None,
    client_request_token: str = None,
    notification_channel: Dict = None,
    job_tag: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Starts asynchronous detection of unsafe content in a stored video. Amazon Rekognition Video can moderate content in a video stored in an Amazon S3 bucket. Use Video to specify the bucket name and the filename of the video. StartContentModeration returns a job identifier (JobId) which you use to get the results of the analysis. When unsafe content analysis is finished, Amazon Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic that you specify in NotificationChannel. To get the results of the unsafe content analysis, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetContentModeration and pass the job identifier (JobId) from the initial call to StartContentModeration.  For more information, see Detecting Unsafe Content in the Amazon Rekognition Developer Guide.

    Args:
        video(Dict): The video in which you want to detect unsafe content. The video must be stored in an Amazon S3 bucket.
        min_confidence(float, optional): Specifies the minimum confidence that Amazon Rekognition must have in order to return a moderated content label. Confidence represents how certain Amazon Rekognition is that the moderated content is correctly identified. 0 is the lowest confidence. 100 is the highest confidence. Amazon Rekognition doesn't return any moderated content labels with a confidence level lower than this specified value. If you don't specify MinConfidence, GetContentModeration returns labels with confidence values greater than or equal to 50 percent. Defaults to None.
        client_request_token(str, optional): Idempotent token used to identify the start request. If you use the same token with multiple StartContentModeration requests, the same JobId is returned. Use ClientRequestToken to prevent the same job from being accidently started more than once. . Defaults to None.
        notification_channel(Dict, optional): The Amazon SNS topic ARN that you want Amazon Rekognition Video to publish the completion status of the unsafe content analysis to. Defaults to None.
        job_tag(str, optional): An identifier you specify that's returned in the completion notification that's published to your Amazon Simple Notification Service topic. For example, you can use JobTag to group related jobs and identify them in the completion notification. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.content_moderation.start(ctx, video=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.content_moderation.start video=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="start_content_moderation",
        op_kwargs={
            "Video": video,
            "MinConfidence": min_confidence,
            "ClientRequestToken": client_request_token,
            "NotificationChannel": notification_channel,
            "JobTag": job_tag,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, task_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels an audit that is in progress. The audit can be either scheduled or on demand. If the audit isn't in progress, an "InvalidRequestException" occurs.

    Args:
        task_id(str): The ID of the audit you want to cancel. You can only cancel an audit that is "IN_PROGRESS".

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.audit.task.cancel(ctx, task_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.audit.task.cancel task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="cancel_audit_task",
        op_kwargs={"taskId": task_id},
    )


async def describe(hub, ctx, task_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a Device Defender audit.

    Args:
        task_id(str): The ID of the audit whose information you want to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.audit.task.describe(ctx, task_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.audit.task.describe task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_audit_task",
        op_kwargs={"taskId": task_id},
    )


async def list_all(
    hub,
    ctx,
    start_time: str,
    end_time: str,
    task_type: str = None,
    task_status: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the Device Defender audits that have been performed during a given time period.

    Args:
        start_time(str): The beginning of the time period. Audit information is retained for a limited time (90 days). Requesting a start time prior to what is retained results in an "InvalidRequestException".
        end_time(str): The end of the time period.
        task_type(str, optional): A filter to limit the output to the specified type of audit: can be one of "ON_DEMAND_AUDIT_TASK" or "SCHEDULED__AUDIT_TASK". Defaults to None.
        task_status(str, optional): A filter to limit the output to audits with the specified completion status: can be one of "IN_PROGRESS", "COMPLETED", "FAILED", or "CANCELED". Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return at one time. The default is 25. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.audit.task.list_all(ctx, start_time=value, end_time=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.audit.task.list_all start_time=value, end_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_audit_tasks",
        op_kwargs={
            "startTime": start_time,
            "endTime": end_time,
            "taskType": task_type,
            "taskStatus": task_status,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, bot_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of aliases for the specified bot.

    Args:
        bot_id(str): The identifier of the bot to list aliases for.
        max_results(int, optional): The maximum number of aliases to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned. Defaults to None.
        next_token(str, optional): If the response from the ListBotAliases operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.aliase.list_all(ctx, bot_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.aliase.list_all bot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="list_bot_aliases",
        op_kwargs={"botId": bot_id, "maxResults": max_results, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, assessment_run_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the assessment run that is specified by the ARN of the assessment run.

    Args:
        assessment_run_arn(str): The ARN that specifies the assessment run that you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.assessment.run.init.delete(
                ctx, assessment_run_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.assessment.run.init.delete assessment_run_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="delete_assessment_run",
        op_kwargs={"assessmentRunArn": assessment_run_arn},
    )


async def describe_all(hub, ctx, assessment_run_arns: List) -> Dict:
    r"""
    **Autogenerated function**

    Describes the assessment runs that are specified by the ARNs of the assessment runs.

    Args:
        assessment_run_arns(List): The ARN that specifies the assessment run that you want to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.assessment.run.init.describe_all(
                ctx, assessment_run_arns=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.assessment.run.init.describe_all assessment_run_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="describe_assessment_runs",
        op_kwargs={"assessmentRunArns": assessment_run_arns},
    )


async def list_all(
    hub,
    ctx,
    assessment_template_arns: List = None,
    filter_: Dict = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the assessment runs that correspond to the assessment templates that are specified by the ARNs of the assessment templates.

    Args:
        assessment_template_arns(List, optional): The ARNs that specify the assessment templates whose assessment runs you want to list. Defaults to None.
        filter_(Dict, optional): You can use this parameter to specify a subset of data to be included in the action's response. For a record to match a filter, all specified filter attributes must match. When multiple values are specified for a filter attribute, any of the values can match. Defaults to None.
        next_token(str, optional): You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListAssessmentRuns action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data. Defaults to None.
        max_results(int, optional): You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 10. The maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.assessment.run.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.assessment.run.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="list_assessment_runs",
        op_kwargs={
            "assessmentTemplateArns": assessment_template_arns,
            "filter": filter_,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def start(
    hub, ctx, assessment_template_arn: str, assessment_run_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Starts the assessment run specified by the ARN of the assessment template. For this API to function properly, you must not exceed the limit of running up to 500 concurrent agents per AWS account.

    Args:
        assessment_template_arn(str): The ARN of the assessment template of the assessment run that you want to start.
        assessment_run_name(str, optional): You can specify the name for the assessment run. The name must be unique for the assessment template whose ARN is used to start the assessment run. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.assessment.run.init.start(
                ctx, assessment_template_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.assessment.run.init.start assessment_template_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="start_assessment_run",
        op_kwargs={
            "assessmentTemplateArn": assessment_template_arn,
            "assessmentRunName": assessment_run_name,
        },
    )


async def stop(hub, ctx, assessment_run_arn: str, stop_action: str = None) -> None:
    r"""
    **Autogenerated function**

    Stops the assessment run that is specified by the ARN of the assessment run.

    Args:
        assessment_run_arn(str): The ARN of the assessment run that you want to stop.
        stop_action(str, optional): An input option that can be set to either START_EVALUATION or SKIP_EVALUATION. START_EVALUATION (the default value), stops the AWS agent from collecting data and begins the results evaluation and the findings generation process. SKIP_EVALUATION cancels the assessment run immediately, after which no findings are generated. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.assessment.run.init.stop(
                ctx, assessment_run_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.assessment.run.init.stop assessment_run_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="stop_assessment_run",
        op_kwargs={"assessmentRunArn": assessment_run_arn, "stopAction": stop_action},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def reset(hub, ctx, distribution_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes currently cached content from your Amazon Lightsail content delivery network (CDN) distribution. After resetting the cache, the next time a content request is made, your distribution pulls, serves, and caches it from the origin.

    Args:
        distribution_name(str, optional): The name of the distribution for which to reset cache. Use the GetDistributions action to get a list of distribution names that you can specify. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.distribution.cache.reset(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.distribution.cache.reset
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="reset_distribution_cache",
        op_kwargs={"distributionName": distribution_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    aws_account_id: str,
    user_name: str,
    namespace: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the IAM policy assignments, including the Amazon Resource Names (ARNs) for the IAM policies assigned to the specified user and group or groups that the user belongs to.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the assignments.
        user_name(str): The name of the user.
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.
        namespace(str): The namespace of the assignment.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.iam_policy_assignment.for_user.list(
                ctx, aws_account_id=value, user_name=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.iam_policy_assignment.for_user.list aws_account_id=value, user_name=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="list_iam_policy_assignments_for_user",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "UserName": user_name,
            "NextToken": next_token,
            "MaxResults": max_results,
            "Namespace": namespace,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def submit(
    hub,
    ctx,
    index_id: str,
    query_id: str,
    click_feedback_items: List = None,
    relevance_feedback_items: List = None,
) -> None:
    r"""
    **Autogenerated function**

    Enables you to provide feedback to Amazon Kendra to improve the performance of your index.

    Args:
        index_id(str): The identifier of the index that was queried.
        query_id(str): The identifier of the specific query for which you are submitting feedback. The query ID is returned in the response to the Query operation.
        click_feedback_items(List, optional): Tells Amazon Kendra that a particular search result link was chosen by the user. . Defaults to None.
        relevance_feedback_items(List, optional): Provides Amazon Kendra with relevant or not relevant feedback for whether a particular item was relevant to the search. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.feedback.submit(ctx, index_id=value, query_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.feedback.submit index_id=value, query_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="submit_feedback",
        op_kwargs={
            "IndexId": index_id,
            "QueryId": query_id,
            "ClickFeedbackItems": click_feedback_items,
            "RelevanceFeedbackItems": relevance_feedback_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def update(hub, ctx, role_name: str, policy_document: str) -> None:
    r"""
    **Autogenerated function**

    Updates the policy that grants an IAM entity permission to assume a role. This is typically referred to as the "role trust policy". For more information about roles, see Using roles to delegate permissions and federate identities.

    Args:
        role_name(str): The name of the role to update with the new policy. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        policy_document(str): The policy that grants an entity permission to assume the role. You must provide policies in JSON format in IAM. However, for CloudFormation templates formatted in YAML, you can provide the policy in JSON or YAML format. CloudFormation always converts a YAML policy to JSON format before submitting it to IAM. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)  .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.assume_role_policy.update(
                ctx, role_name=value, policy_document=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.assume_role_policy.update role_name=value, policy_document=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="update_assume_role_policy",
        op_kwargs={"RoleName": role_name, "PolicyDocument": policy_document},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    workbook_id: str,
    app_id: str,
    screen_id: str,
    variables: Dict = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The GetScreenData API allows retrieval of data from a screen in a Honeycode app. The API allows setting local variables in the screen to filter, sort or otherwise affect what will be displayed on the screen.

    Args:
        workbook_id(str): The ID of the workbook that contains the screen.
        app_id(str): The ID of the app that contains the screem.
        screen_id(str): The ID of the screen.
        variables(Dict, optional):  Variables are optional and are needed only if the screen requires them to render correctly. Variables are specified as a map where the key is the name of the variable as defined on the screen. The value is an object which currently has only one property, rawValue, which holds the value of the variable to be passed to the screen. . Defaults to None.
        max_results(int, optional):  The number of results to be returned on a single page. Specify a number between 1 and 100. The maximum value is 100.   This parameter is optional. If you don't specify this parameter, the default page size is 100. . Defaults to None.
        next_token(str, optional):  This parameter is optional. If a nextToken is not specified, the API returns the first page of data.   Pagination tokens expire after 1 hour. If you use a token that was returned more than an hour back, the API will throw ValidationException. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.honeycode.screen.data.get(
                ctx, workbook_id=value, app_id=value, screen_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.honeycode.screen.data.get workbook_id=value, app_id=value, screen_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="honeycode",
        operation="get_screen_data",
        op_kwargs={
            "workbookId": workbook_id,
            "appId": app_id,
            "screenId": screen_id,
            "variables": variables,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def update_multiple(
    hub, ctx, domain_name: str, nameservers: List, fi_auth_key: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    This operation replaces the current set of name servers for the domain with the specified set of name servers. If you use Amazon Route 53 as your DNS service, specify the four name servers in the delegation set for the hosted zone for the domain. If successful, this operation returns an operation ID that you can use to track the progress and completion of the action. If the request is not completed successfully, the domain registrant will be notified by email.

    Args:
        domain_name(str): The name of the domain that you want to change name servers for.
        fi_auth_key(str, optional): The authorization key for .fi domains. Defaults to None.
        nameservers(List): A list of new name servers for the domain.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.nameserver.update_multiple(
                ctx, domain_name=value, nameservers=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.nameserver.update_multiple domain_name=value, nameservers=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="update_domain_nameservers",
        op_kwargs={
            "DomainName": domain_name,
            "FIAuthKey": fi_auth_key,
            "Nameservers": nameservers,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the current settings of the AWS IoT Events logging options.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.logging_option.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.logging_option.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="describe_logging_options",
        op_kwargs={},
    )


async def put_multiple(hub, ctx, logging_options: Dict) -> None:
    r"""
    **Autogenerated function**

    Sets or updates the AWS IoT Events logging options. If you update the value of any loggingOptions field, it takes up to one minute for the change to take effect. If you change the policy attached to the role you specified in the roleArn field (for example, to correct an invalid policy), it takes up to five minutes for that change to take effect.

    Args:
        logging_options(Dict): The new values of the AWS IoT Events logging options.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.logging_option.put_multiple(ctx, logging_options=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.logging_option.put_multiple logging_options=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="put_logging_options",
        op_kwargs={"loggingOptions": logging_options},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def update(
    hub,
    ctx,
    cluster_arn: str,
    current_version: str,
    target_broker_ebs_volume_info: List,
) -> Dict:
    r"""
        **Autogenerated function**


        Updates the EBS storage associated with MSK brokers.


        Args:
            cluster_arn(str):
    The Amazon Resource Name (ARN) that uniquely identifies the cluster.
    .
            current_version(str):
    The version of cluster to update from. A successful operation will then generate a new version.
    .
            target_broker_ebs_volume_info(List):
    Describes the target volume size and the ID of the broker to apply the update to.
    .

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.broker.storage.update(
                    ctx, cluster_arn=value, current_version=value, target_broker_ebs_volume_info=value
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.broker.storage.update cluster_arn=value, current_version=value, target_broker_ebs_volume_info=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="update_broker_storage",
        op_kwargs={
            "ClusterArn": cluster_arn,
            "CurrentVersion": current_version,
            "TargetBrokerEBSVolumeInfo": target_broker_ebs_volume_info,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, status: str, ascending: str = None, page_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    The ListJobsByStatus operation gets a list of jobs that have a specified status. The response body contains one element for each job that satisfies the search criteria.

    Args:
        status(str): To get information about all of the jobs associated with the current AWS account that have a given status, specify the following status: Submitted, Progressing, Complete, Canceled, or Error.
        ascending(str, optional):  To list jobs in chronological order by the date and time that they were submitted, enter true. To list jobs in reverse chronological order, enter false. . Defaults to None.
        page_token(str, optional):  When Elastic Transcoder returns more than one page of results, use pageToken in subsequent GET requests to get each successive page of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elastictranscoder.jobs_by.status.list(ctx, status=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elastictranscoder.jobs_by.status.list status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elastictranscoder",
        operation="list_jobs_by_status",
        op_kwargs={"Status": status, "Ascending": ascending, "PageToken": page_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    model_id: str,
    model_type: str,
    event_type_name: str,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a model using the specified model type.

    Args:
        model_id(str): The model ID.
        model_type(str): The model type. .
        description(str, optional): The model description. . Defaults to None.
        event_type_name(str): The name of the event type.
        tags(List, optional): A collection of key and value pairs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.model.init.create(
                ctx, model_id=value, model_type=value, event_type_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.model.init.create model_id=value, model_type=value, event_type_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="create_model",
        op_kwargs={
            "modelId": model_id,
            "modelType": model_type,
            "description": description,
            "eventTypeName": event_type_name,
            "tags": tags,
        },
    )


async def delete(hub, ctx, model_id: str, model_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a model. You can delete models and model versions in Amazon Fraud Detector, provided that they are not associated with a detector version.  When you delete a model, Amazon Fraud Detector permanently deletes that model and the data is no longer stored in Amazon Fraud Detector.

    Args:
        model_id(str): The model ID of the model to delete.
        model_type(str): The model type of the model to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.model.init.delete(
                ctx, model_id=value, model_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.model.init.delete model_id=value, model_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="delete_model",
        op_kwargs={"modelId": model_id, "modelType": model_type},
    )


async def get_all(
    hub,
    ctx,
    model_id: str = None,
    model_type: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets one or more models. Gets all models for the AWS account if no model type and no model id provided. Gets all models for the AWS account and model type, if the model type is specified but model id is not provided. Gets a specific model if (model type, model id) tuple is specified.  This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 10 records per page. If you provide a maxResults, the value must be between 1 and 10. To get the next page results, provide the pagination token from the response as part of your request. A null pagination token fetches the records from the beginning.

    Args:
        model_id(str, optional): The model ID. Defaults to None.
        model_type(str, optional): The model type. Defaults to None.
        next_token(str, optional): The next token for the subsequent request. Defaults to None.
        max_results(int, optional): The maximum number of objects to return for the request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.model.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.model.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="get_models",
        op_kwargs={
            "modelId": model_id,
            "modelType": model_type,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub, ctx, model_id: str, model_type: str, description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a model. You can update the description attribute using this action.

    Args:
        model_id(str): The model ID.
        model_type(str): The model type.
        description(str, optional): The new model description. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.model.init.update(
                ctx, model_id=value, model_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.model.init.update model_id=value, model_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="update_model",
        op_kwargs={
            "modelId": model_id,
            "modelType": model_type,
            "description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    client_vpn_endpoint_id: str,
    dry_run: bool = None,
    next_token: str = None,
    filters: List = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the authorization rules for a specified Client VPN endpoint.

    Args:
        client_vpn_endpoint_id(str): The ID of the Client VPN endpoint.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        next_token(str, optional): The token to retrieve the next page of results. Defaults to None.
        filters(List, optional): One or more filters. Filter names and values are case-sensitive.    description - The description of the authorization rule.    destination-cidr - The CIDR of the network to which the authorization rule applies.    group-id - The ID of the Active Directory group to which the authorization rule grants access.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.client_vpn.authorization_rule.describe_all(
                ctx, client_vpn_endpoint_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.client_vpn.authorization_rule.describe_all client_vpn_endpoint_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_client_vpn_authorization_rules",
        op_kwargs={
            "ClientVpnEndpointId": client_vpn_endpoint_id,
            "DryRun": dry_run,
            "NextToken": next_token,
            "Filters": filters,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, domain_name: str, object_type_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a ProfileObjectType from a specific domain as well as removes all the ProfileObjects of that type. It also disables integrations from this specific ProfileObjectType. In addition, it scrubs all of the fields of the standard profile that were populated from this ProfileObjectType.

    Args:
        domain_name(str): The unique name of the domain.
        object_type_name(str): The name of the profile object type.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.profile.object_.type_.init.delete(
                ctx, domain_name=value, object_type_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.profile.object_.type_.init.delete domain_name=value, object_type_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="delete_profile_object_type",
        op_kwargs={"DomainName": domain_name, "ObjectTypeName": object_type_name},
    )


async def get(hub, ctx, domain_name: str, object_type_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the object types for a specific domain.

    Args:
        domain_name(str): The unique name of the domain.
        object_type_name(str): The name of the profile object type.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.profile.object_.type_.init.get(
                ctx, domain_name=value, object_type_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.profile.object_.type_.init.get domain_name=value, object_type_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="get_profile_object_type",
        op_kwargs={"DomainName": domain_name, "ObjectTypeName": object_type_name},
    )


async def list_all(
    hub, ctx, domain_name: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the templates available within the service.

    Args:
        domain_name(str): The unique name of the domain.
        next_token(str, optional): Identifies the next page of results to return. Defaults to None.
        max_results(int, optional): The maximum number of objects returned per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.profile.object_.type_.init.list_all(
                ctx, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.profile.object_.type_.init.list_all domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="list_profile_object_types",
        op_kwargs={
            "DomainName": domain_name,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def put(
    hub,
    ctx,
    domain_name: str,
    object_type_name: str,
    description: str,
    template_id: str = None,
    expiration_days: int = None,
    encryption_key: str = None,
    allow_profile_creation: bool = None,
    fields: Dict = None,
    keys: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Defines a ProfileObjectType.

    Args:
        domain_name(str): The unique name of the domain.
        object_type_name(str): The name of the profile object type.
        description(str): Description of the profile object type.
        template_id(str, optional): A unique identifier for the object template. Defaults to None.
        expiration_days(int, optional): The number of days until the data in the object expires. Defaults to None.
        encryption_key(str, optional): The customer-provided key to encrypt the profile object that will be created in this profile object type. Defaults to None.
        allow_profile_creation(bool, optional): Indicates whether a profile should be created when data is received if one doesn’t exist for an object of this type. The default is FALSE. If the AllowProfileCreation flag is set to FALSE, then the service tries to fetch a standard profile and associate this object with the profile. If it is set to TRUE, and if no match is found, then the service creates a new standard profile. Defaults to None.
        fields(Dict, optional): A map of the name and ObjectType field. Defaults to None.
        keys(Dict, optional): A list of unique keys that can be used to map data to the profile. Defaults to None.
        tags(Dict, optional): The tags used to organize, track, or control access for this resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.profile.object_.type_.init.put(
                ctx, domain_name=value, object_type_name=value, description=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.profile.object_.type_.init.put domain_name=value, object_type_name=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="put_profile_object_type",
        op_kwargs={
            "DomainName": domain_name,
            "ObjectTypeName": object_type_name,
            "Description": description,
            "TemplateId": template_id,
            "ExpirationDays": expiration_days,
            "EncryptionKey": encryption_key,
            "AllowProfileCreation": allow_profile_creation,
            "Fields": fields,
            "Keys": keys,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, instance_id: str, attribute_type: str) -> Dict:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Describes the specified instance attribute.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        attribute_type(str): The type of attribute.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.instance.attribute.describe(
                ctx, instance_id=value, attribute_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.instance.attribute.describe instance_id=value, attribute_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="describe_instance_attribute",
        op_kwargs={"InstanceId": instance_id, "AttributeType": attribute_type},
    )


async def list_all(
    hub, ctx, instance_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Returns a paginated list of all attribute types for the given instance.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.instance.attribute.list_all(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.instance.attribute.list_all instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="list_instance_attributes",
        op_kwargs={
            "InstanceId": instance_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(hub, ctx, instance_id: str, attribute_type: str, value: str) -> None:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Updates the value for the specified attribute type.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        attribute_type(str): The type of attribute.
        value(str): The value for the attribute. Maximum character limit is 100. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.instance.attribute.update(
                ctx, instance_id=value, attribute_type=value, value=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.instance.attribute.update instance_id=value, attribute_type=value, value=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="update_instance_attribute",
        op_kwargs={
            "InstanceId": instance_id,
            "AttributeType": attribute_type,
            "Value": value,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    created_after: str = None,
    created_before: str = None,
    job_flow_ids: List = None,
    job_flow_states: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This API is no longer supported and will eventually be removed. We recommend you use ListClusters, DescribeCluster, ListSteps, ListInstanceGroups and ListBootstrapActions instead. DescribeJobFlows returns a list of job flows that match all of the supplied parameters. The parameters can include a list of job flow IDs, job flow states, and restrictions on job flow creation date and time. Regardless of supplied parameters, only job flows created within the last two months are returned. If no parameters are supplied, then job flows matching either of the following criteria are returned:   Job flows created and completed in the last two weeks    Job flows created within the last two months that are in one of the following states: RUNNING, WAITING, SHUTTING_DOWN, STARTING    Amazon EMR can return a maximum of 512 job flow descriptions.

    Args:
        created_after(str, optional): Return only job flows created after this date and time. Defaults to None.
        created_before(str, optional): Return only job flows created before this date and time. Defaults to None.
        job_flow_ids(List, optional): Return only job flows whose job flow ID is contained in this list. Defaults to None.
        job_flow_states(List, optional): Return only job flows whose state is contained in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.job_flow.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.job_flow.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="describe_job_flows",
        op_kwargs={
            "CreatedAfter": created_after,
            "CreatedBefore": created_before,
            "JobFlowIds": job_flow_ids,
            "JobFlowStates": job_flow_states,
        },
    )


async def run(
    hub,
    ctx,
    name: str,
    instances: Dict,
    log_uri: str = None,
    log_encryption_kms_key_id: str = None,
    additional_info: str = None,
    ami_version: str = None,
    release_label: str = None,
    steps: List = None,
    bootstrap_actions: List = None,
    supported_products: List = None,
    new_supported_products: List = None,
    applications: List = None,
    configurations: List = None,
    visible_to_all_users: bool = None,
    job_flow_role: str = None,
    service_role: str = None,
    tags: List = None,
    security_configuration: str = None,
    auto_scaling_role: str = None,
    scale_down_behavior: str = None,
    custom_ami_id: str = None,
    ebs_root_volume_size: int = None,
    repo_upgrade_on_boot: str = None,
    kerberos_attributes: Dict = None,
    step_concurrency_level: int = None,
    managed_scaling_policy: Dict = None,
    placement_group_configs: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    RunJobFlow creates and starts running a new cluster (job flow). The cluster runs the steps specified. After the steps complete, the cluster stops and the HDFS partition is lost. To prevent loss of data, configure the last step of the job flow to store results in Amazon S3. If the JobFlowInstancesConfig KeepJobFlowAliveWhenNoSteps parameter is set to TRUE, the cluster transitions to the WAITING state rather than shutting down after the steps have completed.  For additional protection, you can set the JobFlowInstancesConfig TerminationProtected parameter to TRUE to lock the cluster and prevent it from being terminated by API call, user intervention, or in the event of a job flow error. A maximum of 256 steps are allowed in each job flow. If your cluster is long-running (such as a Hive data warehouse) or complex, you may require more than 256 steps to process your data. You can bypass the 256-step limitation in various ways, including using the SSH shell to connect to the master node and submitting queries directly to the software running on the master node, such as Hive and Hadoop. For more information on how to do this, see Add More than 256 Steps to a Cluster in the Amazon EMR Management Guide. For long running clusters, we recommend that you periodically store your results.  The instance fleets configuration is available only in Amazon EMR versions 4.8.0 and later, excluding 5.0.x versions. The RunJobFlow request can contain InstanceFleets parameters or InstanceGroups parameters, but not both.

    Args:
        name(str): The name of the job flow.
        log_uri(str, optional): The location in Amazon S3 to write the log files of the job flow. If a value is not provided, logs are not created. Defaults to None.
        log_encryption_kms_key_id(str, optional): The KMS key used for encrypting log files. If a value is not provided, the logs remain encrypted by AES-256. This attribute is only available with Amazon EMR version 5.30.0 and later, excluding Amazon EMR 6.0.0. Defaults to None.
        additional_info(str, optional): A JSON string for selecting additional features. Defaults to None.
        ami_version(str, optional): Applies only to Amazon EMR AMI versions 3.x and 2.x. For Amazon EMR releases 4.0 and later, ReleaseLabel is used. To specify a custom AMI, use CustomAmiID. Defaults to None.
        release_label(str, optional): The Amazon EMR release label, which determines the version of open-source application packages installed on the cluster. Release labels are in the form emr-x.x.x, where x.x.x is an Amazon EMR release version such as emr-5.14.0. For more information about Amazon EMR release versions and included application versions and features, see https://docs.aws.amazon.com/emr/latest/ReleaseGuide/. The release label applies only to Amazon EMR releases version 4.0 and later. Earlier versions use AmiVersion. Defaults to None.
        instances(Dict): A specification of the number and type of Amazon EC2 instances.
        steps(List, optional): A list of steps to run. Defaults to None.
        bootstrap_actions(List, optional): A list of bootstrap actions to run before Hadoop starts on the cluster nodes. Defaults to None.
        supported_products(List, optional):  For Amazon EMR releases 3.x and 2.x. For Amazon EMR releases 4.x and later, use Applications.  A list of strings that indicates third-party software to use. For more information, see the Amazon EMR Developer Guide. Currently supported values are:   "mapr-m3" - launch the job flow using MapR M3 Edition.   "mapr-m5" - launch the job flow using MapR M5 Edition.  . Defaults to None.
        new_supported_products(List, optional):  For Amazon EMR releases 3.x and 2.x. For Amazon EMR releases 4.x and later, use Applications.  A list of strings that indicates third-party software to use with the job flow that accepts a user argument list. EMR accepts and forwards the argument list to the corresponding installation script as bootstrap action arguments. For more information, see "Launch a Job Flow on the MapR Distribution for Hadoop" in the Amazon EMR Developer Guide. Supported values are:   "mapr-m3" - launch the cluster using MapR M3 Edition.   "mapr-m5" - launch the cluster using MapR M5 Edition.   "mapr" with the user arguments specifying "--edition,m3" or "--edition,m5" - launch the job flow using MapR M3 or M5 Edition respectively.   "mapr-m7" - launch the cluster using MapR M7 Edition.   "hunk" - launch the cluster with the Hunk Big Data Analytics Platform.   "hue"- launch the cluster with Hue installed.   "spark" - launch the cluster with Apache Spark installed.   "ganglia" - launch the cluster with the Ganglia Monitoring System installed.  . Defaults to None.
        applications(List, optional): Applies to Amazon EMR releases 4.0 and later. A case-insensitive list of applications for Amazon EMR to install and configure when launching the cluster. For a list of applications available for each Amazon EMR release version, see the Amazon EMR Release Guide. Defaults to None.
        configurations(List, optional): For Amazon EMR releases 4.0 and later. The list of configurations supplied for the EMR cluster you are creating. Defaults to None.
        visible_to_all_users(bool, optional): Set this value to true so that IAM principals in the account associated with the cluster can perform EMR actions on the cluster that their IAM policies allow. This value defaults to false for clusters created using the EMR API or the CLI create-cluster command. When set to false, only the IAM principal that created the cluster and the account root user can perform EMR actions for the cluster, regardless of the IAM permissions policies attached to other IAM principals. For more information, see Understanding the EMR Cluster VisibleToAllUsers Setting in the Amazon EMR Management Guide. Defaults to None.
        job_flow_role(str, optional): Also called instance profile and EC2 role. An IAM role for an EMR cluster. The EC2 instances of the cluster assume this role. The default role is EMR_EC2_DefaultRole. In order to use the default role, you must have already created it using the CLI or console. Defaults to None.
        service_role(str, optional): The IAM role that will be assumed by the Amazon EMR service to access Amazon Web Services resources on your behalf. Defaults to None.
        tags(List, optional): A list of tags to associate with a cluster and propagate to Amazon EC2 instances. Defaults to None.
        security_configuration(str, optional): The name of a security configuration to apply to the cluster. Defaults to None.
        auto_scaling_role(str, optional): An IAM role for automatic scaling policies. The default role is EMR_AutoScaling_DefaultRole. The IAM role provides permissions that the automatic scaling feature requires to launch and terminate EC2 instances in an instance group. Defaults to None.
        scale_down_behavior(str, optional): Specifies the way that individual Amazon EC2 instances terminate when an automatic scale-in activity occurs or an instance group is resized. TERMINATE_AT_INSTANCE_HOUR indicates that Amazon EMR terminates nodes at the instance-hour boundary, regardless of when the request to terminate the instance was submitted. This option is only available with Amazon EMR 5.1.0 and later and is the default for clusters created using that version. TERMINATE_AT_TASK_COMPLETION indicates that Amazon EMR adds nodes to a deny list and drains tasks from nodes before terminating the Amazon EC2 instances, regardless of the instance-hour boundary. With either behavior, Amazon EMR removes the least active nodes first and blocks instance termination if it could lead to HDFS corruption. TERMINATE_AT_TASK_COMPLETION available only in Amazon EMR version 4.1.0 and later, and is the default for versions of Amazon EMR earlier than 5.1.0. Defaults to None.
        custom_ami_id(str, optional): Available only in Amazon EMR version 5.7.0 and later. The ID of a custom Amazon EBS-backed Linux AMI. If specified, Amazon EMR uses this AMI when it launches cluster EC2 instances. For more information about custom AMIs in Amazon EMR, see Using a Custom AMI in the Amazon EMR Management Guide. If omitted, the cluster uses the base Linux AMI for the ReleaseLabel specified. For Amazon EMR versions 2.x and 3.x, use AmiVersion instead. For information about creating a custom AMI, see Creating an Amazon EBS-Backed Linux AMI in the Amazon Elastic Compute Cloud User Guide for Linux Instances. For information about finding an AMI ID, see Finding a Linux AMI. . Defaults to None.
        ebs_root_volume_size(int, optional): The size, in GiB, of the Amazon EBS root device volume of the Linux AMI that is used for each EC2 instance. Available in Amazon EMR version 4.x and later. Defaults to None.
        repo_upgrade_on_boot(str, optional): Applies only when CustomAmiID is used. Specifies which updates from the Amazon Linux AMI package repositories to apply automatically when the instance boots using the AMI. If omitted, the default is SECURITY, which indicates that only security updates are applied. If NONE is specified, no updates are applied, and all updates must be applied manually. Defaults to None.
        kerberos_attributes(Dict, optional): Attributes for Kerberos configuration when Kerberos authentication is enabled using a security configuration. For more information see Use Kerberos Authentication in the Amazon EMR Management Guide. Defaults to None.
        step_concurrency_level(int, optional): Specifies the number of steps that can be executed concurrently. The default value is 1. The maximum value is 256. Defaults to None.
        managed_scaling_policy(Dict, optional):  The specified managed scaling policy for an Amazon EMR cluster. . Defaults to None.
        placement_group_configs(List, optional): The specified placement group configuration for an Amazon EMR cluster. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.job_flow.init.run(ctx, name=value, instances=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.job_flow.init.run name=value, instances=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="run_job_flow",
        op_kwargs={
            "Name": name,
            "LogUri": log_uri,
            "LogEncryptionKmsKeyId": log_encryption_kms_key_id,
            "AdditionalInfo": additional_info,
            "AmiVersion": ami_version,
            "ReleaseLabel": release_label,
            "Instances": instances,
            "Steps": steps,
            "BootstrapActions": bootstrap_actions,
            "SupportedProducts": supported_products,
            "NewSupportedProducts": new_supported_products,
            "Applications": applications,
            "Configurations": configurations,
            "VisibleToAllUsers": visible_to_all_users,
            "JobFlowRole": job_flow_role,
            "ServiceRole": service_role,
            "Tags": tags,
            "SecurityConfiguration": security_configuration,
            "AutoScalingRole": auto_scaling_role,
            "ScaleDownBehavior": scale_down_behavior,
            "CustomAmiId": custom_ami_id,
            "EbsRootVolumeSize": ebs_root_volume_size,
            "RepoUpgradeOnBoot": repo_upgrade_on_boot,
            "KerberosAttributes": kerberos_attributes,
            "StepConcurrencyLevel": step_concurrency_level,
            "ManagedScalingPolicy": managed_scaling_policy,
            "PlacementGroupConfigs": placement_group_configs,
        },
    )


async def terminate(hub, ctx, job_flow_ids: List) -> None:
    r"""
    **Autogenerated function**

    TerminateJobFlows shuts a list of clusters (job flows) down. When a job flow is shut down, any step not yet completed is canceled and the EC2 instances on which the cluster is running are stopped. Any log files not already saved are uploaded to Amazon S3 if a LogUri was specified when the cluster was created. The maximum number of clusters allowed is 10. The call to TerminateJobFlows is asynchronous. Depending on the configuration of the cluster, it may take up to 1-5 minutes for the cluster to completely terminate and release allocated resources, such as Amazon EC2 instances.

    Args:
        job_flow_ids(List): A list of job flows to be shut down.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.job_flow.init.terminate(ctx, job_flow_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.job_flow.init.terminate job_flow_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="terminate_job_flows",
        op_kwargs={"JobFlowIds": job_flow_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, directory_id: str, log_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a subscription to forward real-time Directory Service domain controller security logs to the specified Amazon CloudWatch log group in your AWS account.

    Args:
        directory_id(str): Identifier of the directory to which you want to subscribe and receive real-time logs to your specified CloudWatch log group.
        log_group_name(str): The name of the CloudWatch log group where the real-time domain controller logs are forwarded.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.log_subscription.create(
                ctx, directory_id=value, log_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.log_subscription.create directory_id=value, log_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="create_log_subscription",
        op_kwargs={"DirectoryId": directory_id, "LogGroupName": log_group_name},
    )


async def delete(hub, ctx, directory_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified log subscription.

    Args:
        directory_id(str): Identifier of the directory whose log subscription you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.log_subscription.delete(ctx, directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.log_subscription.delete directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="delete_log_subscription",
        op_kwargs={"DirectoryId": directory_id},
    )


async def list_all(
    hub, ctx, directory_id: str = None, next_token: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the active log subscriptions for the AWS account.

    Args:
        directory_id(str, optional): If a DirectoryID is provided, lists only the log subscription associated with that directory. If no DirectoryId is provided, lists all log subscriptions associated with your AWS account. If there are no log subscriptions for the AWS account or the directory, an empty list will be returned. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. Defaults to None.
        limit(int, optional): The maximum number of items returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.log_subscription.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.log_subscription.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="list_log_subscriptions",
        op_kwargs={
            "DirectoryId": directory_id,
            "NextToken": next_token,
            "Limit": limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def search(
    hub,
    ctx,
    bucket_criteria: Dict = None,
    max_results: int = None,
    next_token: str = None,
    sort_criteria: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves (queries) statistical data and other information about Amazon Web Services resources that Amazon Macie monitors and analyzes.

    Args:
        bucket_criteria(Dict, optional): The filter conditions that determine which S3 buckets to include or exclude from the query results. Defaults to None.
        max_results(int, optional): The maximum number of items to include in each page of the response. The default value is 50. Defaults to None.
        next_token(str, optional): The nextToken string that specifies which page of results to return in a paginated response. Defaults to None.
        sort_criteria(Dict, optional): The criteria to use to sort the results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.resource.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.resource.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="search_resources",
        op_kwargs={
            "bucketCriteria": bucket_criteria,
            "maxResults": max_results,
            "nextToken": next_token,
            "sortCriteria": sort_criteria,
        },
    )


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Adds or updates one or more tags (keys and values) that are associated with a classification job, custom data identifier, findings filter, or member account.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the classification job, custom data identifier, findings filter, or member account.
        tags(Dict): A map of key-value pairs that specifies the tags to associate with the resource. A resource can have a maximum of 50 tags. Each tag consists of a tag key and an associated tag value. The maximum length of a tag key is 128 characters. The maximum length of a tag value is 256 characters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="tag_resource",
        op_kwargs={"resourceArn": resource_arn, "tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes one or more tags (keys and values) from a classification job, custom data identifier, findings filter, or member account.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the classification job, custom data identifier, findings filter, or member account.
        tag_keys(List): The key of the tag to remove from the resource. To remove multiple tags, append the tagKeys parameter and argument for each additional tag to remove, separated by an ampersand (&).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="untag_resource",
        op_kwargs={"resourceArn": resource_arn, "tagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "block_list"


async def create(
    hub,
    ctx,
    index_id: str,
    name: str,
    source_s3_path: Dict,
    role_arn: str,
    description: str = None,
    client_token: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a block list to exlcude certain queries from suggestions. Any query that contains words or phrases specified in the block list is blocked or filtered out from being shown as a suggestion. You need to provide the file location of your block list text file in your S3 bucket. In your text file, enter each block word or phrase on a separate line. For information on the current quota limits for block lists, see Quotas for Amazon Kendra.

    Args:
        index_id(str): The identifier of the index you want to create a query suggestions block list for.
        name(str): A user friendly name for the block list. For example, the block list named 'offensive-words' includes all offensive words that could appear in user queries and need to be blocked from suggestions.
        description(str, optional): A user-friendly description for the block list. For example, the description "List of all offensive words that can appear in user queries and need to be blocked from suggestions.". Defaults to None.
        source_s3_path(Dict): The S3 path to your block list text file in your S3 bucket. Each block word or phrase should be on a separate line in a text file. For information on the current quota limits for block lists, see Quotas for Amazon Kendra.
        client_token(str, optional): A token that you provide to identify the request to create a query suggestions block list. Defaults to None.
        role_arn(str): The IAM (Identity and Access Management) role used by Amazon Kendra to access the block list text file in your S3 bucket. You need permissions to the role ARN (Amazon Resource Name). The role needs S3 read permissions to your file in S3 and needs to give STS (Security Token Service) assume role permissions to Amazon Kendra.
        tags(List, optional): A tag that you can assign to a block list that categorizes the block list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.query_suggestion.block_list_.create(
                ctx, index_id=value, name=value, source_s3_path=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.query_suggestion.block_list.create index_id=value, name=value, source_s3_path=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="create_query_suggestions_block_list",
        op_kwargs={
            "IndexId": index_id,
            "Name": name,
            "Description": description,
            "SourceS3Path": source_s3_path,
            "ClientToken": client_token,
            "RoleArn": role_arn,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, index_id: str, id_: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a block list used for query suggestions for an index. A deleted block list might not take effect right away. Amazon Kendra needs to refresh the entire suggestions list to add back the queries that were previously blocked.

    Args:
        index_id(str): The identifier of the you want to delete a block list from.
        id_(str): The unique identifier of the block list that needs to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.query_suggestion.block_list_.delete(
                ctx, index_id=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.query_suggestion.block_list.delete index_id=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="delete_query_suggestions_block_list",
        op_kwargs={"IndexId": index_id, "Id": id_},
    )


async def describe(hub, ctx, index_id: str, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a block list used for query suggestions for an index. This is used to check the current settings that are applied to a block list.

    Args:
        index_id(str): The identifier of the index for the block list.
        id_(str): The unique identifier of the block list.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.query_suggestion.block_list_.describe(
                ctx, index_id=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.query_suggestion.block_list.describe index_id=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="describe_query_suggestions_block_list",
        op_kwargs={"IndexId": index_id, "Id": id_},
    )


async def list_all(
    hub, ctx, index_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the block lists used for query suggestions for an index. For information on the current quota limits for block lists, see Quotas for Amazon Kendra.

    Args:
        index_id(str): The identifier of the index for a list of all block lists that exist for that index. For information on the current quota limits for block lists, see Quotas for Amazon Kendra.
        next_token(str, optional): If the previous response was incomplete (because there is more data to retrieve), Amazon Kendra returns a pagination token in the response. You can use this pagination token to retrieve the next set of block lists (BlockListSummaryItems). Defaults to None.
        max_results(int, optional): The maximum number of block lists to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.query_suggestion.block_list_.list_all(
                ctx, index_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.query_suggestion.block_list.list_all index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="list_query_suggestions_block_lists",
        op_kwargs={
            "IndexId": index_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    index_id: str,
    id_: str,
    name: str = None,
    description: str = None,
    source_s3_path: Dict = None,
    role_arn: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates a block list used for query suggestions for an index. Updates to a block list might not take effect right away. Amazon Kendra needs to refresh the entire suggestions list to apply any updates to the block list. Other changes not related to the block list apply immediately. If a block list is updating, then you need to wait for the first update to finish before submitting another update. Amazon Kendra supports partial updates, so you only need to provide the fields you want to update.

    Args:
        index_id(str): The identifier of the index for a block list.
        id_(str): The unique identifier of a block list.
        name(str, optional): The name of a block list. Defaults to None.
        description(str, optional): The description for a block list. Defaults to None.
        source_s3_path(Dict, optional): The S3 path where your block list text file sits in S3. If you update your block list and provide the same path to the block list text file in S3, then Amazon Kendra reloads the file to refresh the block list. Amazon Kendra does not automatically refresh your block list. You need to call the UpdateQuerySuggestionsBlockList API to refresh you block list. If you update your block list, then Amazon Kendra asynchronously refreshes all query suggestions with the latest content in the S3 file. This means changes might not take effect immediately. Defaults to None.
        role_arn(str, optional): The IAM (Identity and Access Management) role used to access the block list text file in S3. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.query_suggestion.block_list_.update(
                ctx, index_id=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.query_suggestion.block_list.update index_id=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="update_query_suggestions_block_list",
        op_kwargs={
            "IndexId": index_id,
            "Id": id_,
            "Name": name,
            "Description": description,
            "SourceS3Path": source_s3_path,
            "RoleArn": role_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub, ctx, fleet_ids: List = None, limit: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves utilization statistics for one or more fleets. Utilization data provides a snapshot of how the fleet's hosting resources are currently being used. For fleets with remote locations, this operation retrieves data for the fleet's home Region only. See DescribeFleetLocationUtilization to get utilization statistics for a fleet's remote locations. This operation can be used in the following ways:    To get utilization data for one or more specific fleets, provide a list of fleet IDs or fleet ARNs.    To get utilization data for all fleets, do not provide a fleet identifier.    When requesting multiple fleets, use the pagination parameters to retrieve results as a set of sequential pages.  If successful, a FleetUtilization object is returned for each requested fleet ID, unless the fleet identifier is not found. Each fleet utilization object includes a Location property, which is set to the fleet's home Region.   Some API operations may limit the number of fleet IDs allowed in one request. If a request exceeds this limit, the request fails and the error message includes the maximum allowed.   Learn more   Setting up GameLift Fleets   GameLift Metrics for Fleets   Related actions   ListFleets | DescribeEC2InstanceLimits | DescribeFleetAttributes | DescribeFleetCapacity | DescribeFleetEvents | DescribeFleetLocationAttributes | DescribeFleetPortSettings | DescribeFleetUtilization | DescribeRuntimeConfiguration | DescribeScalingPolicies | All APIs by task

    Args:
        fleet_ids(List, optional): A unique identifier for the fleet(s) to retrieve utilization data for. You can use either the fleet ID or ARN value. To retrieve attributes for all current fleets, do not include this parameter. . Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. This parameter is ignored when the request specifies one or a list of fleet IDs. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. This parameter is ignored when the request specifies one or a list of fleet IDs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.utilization.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.utilization.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_fleet_utilization",
        op_kwargs={"FleetIds": fleet_ids, "Limit": limit, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, start_selector: Dict, stream_name: str = None, stream_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Use this API to retrieve media content from a Kinesis video stream. In the request, you identify the stream name or stream Amazon Resource Name (ARN), and the starting chunk. Kinesis Video Streams then returns a stream of chunks in order by fragment number.  You must first call the GetDataEndpoint API to get an endpoint. Then send the GetMedia requests to this endpoint using the --endpoint-url parameter.   When you put media data (fragments) on a stream, Kinesis Video Streams stores each incoming fragment and related metadata in what is called a "chunk." For more information, see PutMedia. The GetMedia API returns a stream of these chunks starting from the chunk that you specify in the request.  The following limits apply when using the GetMedia API:   A client can call GetMedia up to five times per second per stream.    Kinesis Video Streams sends media data at a rate of up to 25 megabytes per second (or 200 megabits per second) during a GetMedia session.     If an error is thrown after invoking a Kinesis Video Streams media API, in addition to the HTTP status code and the response body, it includes the following pieces of information:     x-amz-ErrorType HTTP header – contains a more specific error type in addition to what the HTTP status code provides.     x-amz-RequestId HTTP header – if you want to report an issue to AWS, the support team can better diagnose the problem if given the Request Id.   Both the HTTP status code and the ErrorType header can be utilized to make programmatic decisions about whether errors are retry-able and under what conditions, as well as provide information on what actions the client programmer might need to take in order to successfully try again. For more information, see the Errors section at the bottom of this topic, as well as Common Errors.

    Args:
        stream_name(str, optional): The Kinesis video stream name from where you want to get the media content. If you don't specify the streamName, you must specify the streamARN. Defaults to None.
        stream_arn(str, optional): The ARN of the stream from where you want to get the media content. If you don't specify the streamARN, you must specify the streamName. Defaults to None.
        start_selector(Dict): Identifies the starting chunk to get from the specified stream. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis_video_media_media.get(ctx, start_selector=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis_video_media_media.get start_selector=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis-video-media",
        operation="get_media",
        op_kwargs={
            "StreamName": stream_name,
            "StreamARN": stream_arn,
            "StartSelector": start_selector,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, job_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the results for an Amazon Textract asynchronous operation that detects text in a document. Amazon Textract can detect lines of text and the words that make up a line of text. You start asynchronous text detection by calling StartDocumentTextDetection, which returns a job identifier (JobId). When the text detection operation finishes, Amazon Textract publishes a completion status to the Amazon Simple Notification Service (Amazon SNS) topic that's registered in the initial call to StartDocumentTextDetection. To get the results of the text-detection operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetDocumentTextDetection, and pass the job identifier (JobId) from the initial call to StartDocumentTextDetection.  GetDocumentTextDetection returns an array of Block objects.  Each document page has as an associated Block of type PAGE. Each PAGE Block object is the parent of LINE Block objects that represent the lines of detected text on a page. A LINE Block object is a parent for each word that makes up the line. Words are represented by Block objects of type WORD. Use the MaxResults parameter to limit the number of blocks that are returned. If there are more results than specified in MaxResults, the value of NextToken in the operation response contains a pagination token for getting the next set of results. To get the next page of results, call GetDocumentTextDetection, and populate the NextToken request parameter with the token value that's returned from the previous call to GetDocumentTextDetection. For more information, see Document Text Detection.

    Args:
        job_id(str): A unique identifier for the text detection job. The JobId is returned from StartDocumentTextDetection. A JobId value is only valid for 7 days.
        max_results(int, optional): The maximum number of results to return per paginated call. The largest value you can specify is 1,000. If you specify a value greater than 1,000, a maximum of 1,000 results is returned. The default value is 1,000. Defaults to None.
        next_token(str, optional): If the previous response was incomplete (because there are more blocks to retrieve), Amazon Textract returns a pagination token in the response. You can use this pagination token to retrieve the next set of blocks. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.textract.document.text.detection.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.textract.document.text.detection.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="textract",
        operation="get_document_text_detection",
        op_kwargs={"JobId": job_id, "MaxResults": max_results, "NextToken": next_token},
    )


async def start(
    hub,
    ctx,
    document_location: Dict,
    client_request_token: str = None,
    job_tag: str = None,
    notification_channel: Dict = None,
    output_config: Dict = None,
    kms_key_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts the asynchronous detection of text in a document. Amazon Textract can detect lines of text and the words that make up a line of text.  StartDocumentTextDetection can analyze text in documents that are in JPEG, PNG, and PDF format. The documents are stored in an Amazon S3 bucket. Use DocumentLocation to specify the bucket name and file name of the document.   StartTextDetection returns a job identifier (JobId) that you use to get the results of the operation. When text detection is finished, Amazon Textract publishes a completion status to the Amazon Simple Notification Service (Amazon SNS) topic that you specify in NotificationChannel. To get the results of the text detection operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetDocumentTextDetection, and pass the job identifier (JobId) from the initial call to StartDocumentTextDetection. For more information, see Document Text Detection.

    Args:
        document_location(Dict): The location of the document to be processed.
        client_request_token(str, optional): The idempotent token that's used to identify the start request. If you use the same token with multiple StartDocumentTextDetection requests, the same JobId is returned. Use ClientRequestToken to prevent the same job from being accidentally started more than once. For more information, see Calling Amazon Textract Asynchronous Operations. Defaults to None.
        job_tag(str, optional): An identifier that you specify that's included in the completion notification published to the Amazon SNS topic. For example, you can use JobTag to identify the type of document that the completion notification corresponds to (such as a tax form or a receipt). Defaults to None.
        notification_channel(Dict, optional): The Amazon SNS topic ARN that you want Amazon Textract to publish the completion status of the operation to. . Defaults to None.
        output_config(Dict, optional): Sets if the output will go to a customer defined bucket. By default Amazon Textract will save the results internally to be accessed with the GetDocumentTextDetection operation. Defaults to None.
        kms_key_id(str, optional): The KMS key used to encrypt the inference results. This can be in either Key ID or Key Alias format. When a KMS key is provided, the KMS key will be used for server-side encryption of the objects in the customer bucket. When this parameter is not enabled, the result will be encrypted server side,using SSE-S3. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.textract.document.text.detection.start(
                ctx, document_location=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.textract.document.text.detection.start document_location=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="textract",
        operation="start_document_text_detection",
        op_kwargs={
            "DocumentLocation": document_location,
            "ClientRequestToken": client_request_token,
            "JobTag": job_tag,
            "NotificationChannel": notification_channel,
            "OutputConfig": output_config,
            "KMSKeyId": kms_key_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, repository_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about one or more repositories.  The description field for a repository accepts all HTML characters and all valid Unicode characters. Applications that do not HTML-encode the description and display it in a webpage can expose users to potentially malicious code. Make sure that you HTML-encode the description field in any application that uses this API to display the repository description on a webpage.

    Args:
        repository_names(List): The names of the repositories to get information about.  The length constraint limit is for each string in the array. The array itself can be empty. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.get.repository.batch(ctx, repository_names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.get.repository.batch repository_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="batch_get_repositories",
        op_kwargs={"repositoryNames": repository_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def discover(
    hub,
    ctx,
    service_execution_role: str,
    resource_arn: str = None,
    input_starting_position_configuration: Dict = None,
    s3_configuration: Dict = None,
    input_processing_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Infers a schema for a SQL-based Kinesis Data Analytics application by evaluating sample records on the specified streaming source (Kinesis data stream or Kinesis Data Firehose delivery stream) or Amazon S3 object. In the response, the operation returns the inferred schema and also the sample records that the operation used to infer the schema.  You can use the inferred schema when configuring a streaming source for your application. When you create an application using the Kinesis Data Analytics console, the console uses this operation to infer a schema and show it in the console user interface.

    Args:
        resource_arn(str, optional): The Amazon Resource Name (ARN) of the streaming source. Defaults to None.
        service_execution_role(str): The ARN of the role that is used to access the streaming source.
        input_starting_position_configuration(Dict, optional): The point at which you want Kinesis Data Analytics to start reading records from the specified streaming source discovery purposes. Defaults to None.
        s3_configuration(Dict, optional): Specify this parameter to discover a schema from data in an Amazon S3 object. Defaults to None.
        input_processing_configuration(Dict, optional): The InputProcessingConfiguration to use to preprocess the records before discovering the schema of the records. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.input_schema.discover(
                ctx, service_execution_role=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.input_schema.discover service_execution_role=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="discover_input_schema",
        op_kwargs={
            "ResourceARN": resource_arn,
            "ServiceExecutionRole": service_execution_role,
            "InputStartingPositionConfiguration": input_starting_position_configuration,
            "S3Configuration": s3_configuration,
            "InputProcessingConfiguration": input_processing_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    configuration_aggregator_name: str,
    filters: Dict = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of compliant and noncompliant rules with the number of resources for compliant and noncompliant rules.   The results can return an empty result page, but if you have a nextToken, the results are displayed on the next page.

    Args:
        configuration_aggregator_name(str): The name of the configuration aggregator.
        filters(Dict, optional): Filters the results by ConfigRuleComplianceFilters object. . Defaults to None.
        limit(int, optional): The maximum number of evaluation results returned on each page. The default is maximum. If you specify 0, AWS Config uses the default. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.aggregate.compliance.by.config_rule.describe_all(
                ctx, configuration_aggregator_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.aggregate.compliance.by.config_rule.describe_all configuration_aggregator_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_aggregate_compliance_by_config_rules",
        op_kwargs={
            "ConfigurationAggregatorName": configuration_aggregator_name,
            "Filters": filters,
            "Limit": limit,
            "NextToken": next_token,
        },
    )
